Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1487)

Unified Diff: runtime/bin/filter_patch.dart

Issue 130513003: [ZLIB] Add support for windowBits, memLevel, raw (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: integrate feedback Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/filter.cc ('k') | runtime/bin/io_natives.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/filter_patch.dart
diff --git a/runtime/bin/filter_patch.dart b/runtime/bin/filter_patch.dart
index 1dc727d4ea035b4e6f72cbe5ec7619cae6cee1af..d8109fda5effbd7ecf04601e98ad241c9bb7ee2f 100644
--- a/runtime/bin/filter_patch.dart
+++ b/runtime/bin/filter_patch.dart
@@ -13,22 +13,33 @@ class _FilterImpl extends NativeFieldWrapperClass1 implements _Filter {
}
class _ZLibInflateFilter extends _FilterImpl {
- _ZLibInflateFilter() {
- _init();
+ _ZLibInflateFilter(int windowBits, List<int> dictionary, bool raw) {
+ _init(windowBits, dictionary, raw);
}
- void _init() native "Filter_CreateZLibInflate";
+ void _init(int windowBits, List<int> dictionary, bool raw)
+ native "Filter_CreateZLibInflate";
}
class _ZLibDeflateFilter extends _FilterImpl {
- _ZLibDeflateFilter(bool gzip, int level) {
- _init(gzip, level);
+ _ZLibDeflateFilter(bool gzip, int level, int windowBits, int memLevel,
+ int strategy, List<int> dictionary, bool raw) {
+ _init(gzip, level, windowBits, memLevel, strategy, dictionary, raw);
}
- void _init(bool gzip, int level) native "Filter_CreateZLibDeflate";
+ void _init(bool gzip, int level, int windowBits, int memLevel,
+ int strategy, List<int> dictionary, bool raw)
+ native "Filter_CreateZLibDeflate";
}
patch class _Filter {
- /* patch */ static _Filter newZLibDeflateFilter(bool gzip, int level)
- => new _ZLibDeflateFilter(gzip, level);
- /* patch */ static _Filter newZLibInflateFilter() => new _ZLibInflateFilter();
+ /* patch */ static _Filter newZLibDeflateFilter(bool gzip, int level,
+ int windowBits, int memLevel,
+ int strategy,
+ List<int> dictionary,
+ bool raw) =>
+ new _ZLibDeflateFilter(gzip, level, windowBits, memLevel, strategy,
+ dictionary, raw);
+ /* patch */ static _Filter newZLibInflateFilter(int windowBits,
+ List<int> dictionary,
+ bool raw) =>
+ new _ZLibInflateFilter(windowBits, dictionary, raw);
}
-
« no previous file with comments | « runtime/bin/filter.cc ('k') | runtime/bin/io_natives.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698